@@ -108,7 +108,6 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 	GnomeVFSURI *vfs_uri;
 	char *error_message;
 	char *name;
-	char *icon;
 	int type;
 	
 	type = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->details->type_combo));
@@ -121,42 +120,53 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 		vfs_uri = gnome_vfs_uri_new (uri);
 		
 		if (vfs_uri == NULL) {
-			error_message = g_strdup_printf
-				(_("\"%s\" is not a valid location."),
-				 uri);
+			GtkWidget *dlg;
+
+			error_message = g_strdup_printf (_("\"%s\" is not a valid location."), uri);
 			
-			GtkWidget* dialog = gtk_message_dialog_new(NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_OK,
-				error_message);
-			gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-				_("Please check the spelling and try again."));	
-			gtk_dialog_run (GTK_DIALOG (dialog));
-    			gtk_widget_destroy (dialog);
+			dlg = gtk_message_dialog_new (GTK_WINDOW (dialog),
+						      GTK_DIALOG_DESTROY_WITH_PARENT,
+						      GTK_MESSAGE_ERROR,
+						      GTK_BUTTONS_OK,
+						      error_message);
+
+			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
+					_("Please check the spelling and try again."));
+
 			g_free(error_message);
+
+			gtk_dialog_run (GTK_DIALOG (dlg));
+    			gtk_widget_destroy (dlg);
+
 			return FALSE;
-			
-		} else {
+		}
+		else {
 			gnome_vfs_uri_unref (vfs_uri);
 		}
-	} else {
-		char *method, *user, *port, *initial_path, *server, *folder ,*domain ;
+	}
+	else {
+		char *method, *user, *port, *initial_path, *server, *folder, *domain;
 		char *t, *join;
 		gboolean free_initial_path, free_user, free_domain, free_port;
 
 		server = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->server_entry), 0, -1);
 		if (strlen (server) == 0) {
-			GtkWidget* dialog = gtk_message_dialog_new(NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_OK,
-				_("You must enter a name for the server."));
-			gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-				_("Please enter a name and try again."));	
-			gtk_dialog_run (GTK_DIALOG (dialog));
-    			gtk_widget_destroy (dialog);
+			GtkWidget *dlg;
+
+			dlg = gtk_message_dialog_new (GTK_WINDOW (dialog),
+						      GTK_DIALOG_DESTROY_WITH_PARENT,
+						      GTK_MESSAGE_ERROR,
+						      GTK_BUTTONS_OK,
+						      _("You must enter a name for the server."));
+
+			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
+					_("Please enter a name and try again."));
+
 			g_free(server);
+
+			gtk_dialog_run (GTK_DIALOG (dlg));
+    			gtk_widget_destroy (dlg);
+
 			return FALSE;
 		}
 		
@@ -296,18 +306,7 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 		}
 		gnome_vfs_uri_unref (vfs_uri);
 	}
-		
-	if (g_str_has_prefix (uri, "smb:")) {
-		icon = "gnome-fs-smb";
-	} else if (g_str_has_prefix (uri, "ssh:") ||
-		   g_str_has_prefix (uri, "sftp:")) {
-		icon = "gnome-fs-ssh";
-	} else if (g_str_has_prefix (uri, "ftp:")) {
-		icon = "gnome-fs-ftp";
-	} else {
-		icon = "gnome-fs-share";
-	}
-	
+
 	g_string_assign(baobab.last_scan_command,uri);
 	
 	g_free (uri);
